@@ -142,6 +142,24 @@ char cp852_2_sym[128][3] = {
 "00", "00", "00", "00", "00", "00", "B8", "00", 
 "B0", "00", "00", "00", "00", "00", "00", "00", 
 };
+char cp852_2_1250[256][3] = {
+"C7", "FC", "E9", "E2", "E4", "F9", "E6", "E7", 
+"B3", "EB", "D5", "F5", "EE", "8F", "C4", "C6", 
+"C9", "C5", "E5", "F4", "F6", "BC", "BE", "8C", 
+"9C", "D6", "DC", "8D", "9D", "A3", "D7", "E8", 
+"E1", "ED", "F3", "FA", "A5", "B9", "8E", "9E", 
+"CA", "EA", "00", "9F", "C8", "BA", "AB", "BB", 
+"00", "00", "00", "00", "00", "C1", "C2", "CC", 
+"AA", "00", "00", "00", "00", "AF", "BF", "00", 
+"00", "00", "00", "00", "00", "00", "C3", "E3", 
+"00", "00", "00", "00", "00", "00", "00", "A4", 
+"F0", "D0", "CF", "CB", "EF", "D2", "CD", "CE", 
+"EC", "00", "00", "00", "00", "DE", "D9", "00", 
+"D3", "DF", "D4", "D1", "F1", "F2", "8A", "9A", 
+"C0", "DA", "E0", "DB", "FD", "DD", "FE", "B4", 
+"AD", "BD", "B2", "A1", "A2", "A7", "F7", "B8", 
+"B0", "A8", "FF", "FB", "D8", "F8", "00", "A0", 
+};
 char cp865_2_ansi[128][3] = {
 "C7", "FC", "E9", "E2", "E4", "E0", "E5", "E7", 
 "EA", "EB", "E8", "EF", "EE", "EC", "C4", "C5", 
@@ -214,6 +232,24 @@ char cp1250_2_sym[128][3] = {
 "00", "00", "00", "00", "00", "00", "00", "B8", 
 "00", "00", "00", "00", "00", "00", "00", "00", 
 };
+char cp1250_2_1250[256][3] = {
+"80", "00", "82", "00", "84", "85", "86", "87", 
+"00", "89", "8A", "8B", "8C", "8D", "8E", "8F", 
+"00", "91", "92", "93", "94", "95", "96", "97", 
+"00", "99", "9A", "9B", "9C", "9D", "9E", "9F", 
+"A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", 
+"A8", "A9", "AA", "AB", "00", "AD", "AE", "AF", 
+"B0", "B1", "B2", "B3", "B4", "B5", "B6", "B7", 
+"B8", "B9", "BA", "BB", "BC", "BD", "BE", "BF", 
+"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
+"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
+"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
+"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
+"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
+"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
+"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
+"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
+};
 char cp1252_2_ansi[128][3] = {
 "00", "00", "82", "83", "84", "85", "86", "87", 
 "88", "89", "8A", "8B", "8C", "00", "00", "00", 
@@ -358,6 +394,25 @@ char latin2_2_sym[128][3] = {
 "00", "00", "00", "00", "00", "00", "00", "B8", 
 "00", "00", "00", "00", "00", "00", "00", "00", 
 };
+char latin2_2_1250[256][3] = {
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"A0", "A5", "A2", "A3", "A4", "BC", "8C", "A7", 
+"A8", "8A", "AA", "8D", "8F", "AD", "8E", "AF", 
+"B0", "B9", "B2", "B3", "B4", "BE", "9C", "A1", 
+"B8", "9A", "BA", "9D", "9F", "BD", "9E", "BF", 
+"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
+"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
+"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
+"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
+"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
+"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
+"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
+"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
+};
+
 char latin3_2_ansi[128][3] = {
 "00", "00", "00", "00", "00", "00", "00", "00", 
 "00", "00", "00", "00", "00", "00", "00", "00", 
@@ -539,3 +594,131 @@ char next_2_sym[128][3] = {
 "00", "00", "00", "00", "00", "00", "00", "00", 
 };
 
+/* Cyrillic Encodings */
+
+char cp1251_2_cp1251[128][3] = {
+"80", "81", "82", "83", "84", "85", "86", "87", 
+"88", "89", "8A", "8B", "8C", "8D", "8E", "8F", 
+"90", "91", "92", "93", "94", "95", "96", "97", 
+"00", "99", "9A", "9B", "9C", "9D", "9E", "9F", 
+"A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", 
+"A8", "A9", "AA", "AB", "AC", "AD", "AE", "AF", 
+"B0", "B1", "B2", "B3", "B4", "B5", "B6", "B7", 
+"B8", "B9", "BA", "BB", "BC", "BD", "BE", "BF", 
+"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
+"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
+"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
+"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
+"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
+"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
+"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
+"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
+};
+char cp855_2_cp1251[128][3] = {
+"90", "80", "83", "81", "B8", "A8", "BA", "AA", 
+"BE", "BD", "B3", "B2", "BF", "AF", "BC", "A3", 
+"9A", "8A", "9C", "8C", "9E", "8E", "9D", "8D", 
+"A2", "A1", "9F", "8F", "FE", "DE", "FA", "DA", 
+"E0", "C0", "E1", "C1", "F6", "D6", "E4", "C4", 
+"E5", "C5", "F4", "D4", "E3", "C3", "AB", "BB", 
+"00", "00", "00", "00", "00", "F5", "D5", "E8", 
+"C8", "00", "00", "00", "00", "E9", "C9", "00", 
+"00", "00", "00", "00", "00", "00", "EA", "CA", 
+"00", "00", "00", "00", "00", "00", "00", "A4", 
+"EB", "CB", "EC", "CC", "ED", "CD", "EE", "CE", 
+"EF", "00", "00", "00", "00", "CF", "FF", "00", 
+"DF", "F0", "D0", "F1", "D1", "F2", "D2", "F3", 
+"D3", "E6", "C6", "E2", "C2", "FC", "DC", "B9", 
+"AD", "FB", "DB", "E7", "C7", "F8", "D8", "FD", 
+"DD", "F9", "D9", "F7", "D7", "A7", "00", "A0", 
+};
+char cp866_2_cp1251[128][3] = {
+"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
+"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
+"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
+"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
+"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
+"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
+"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
+"A8", "B8", "AA", "BA", "AF", "BF", "A1", "A2", 
+"B0", "95", "B7", "00", "B9", "A4", "00", "A0", 
+};
+char koi8r_2_cp1251[128][3] = {
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "95", "00", "00", 
+"00", "00", "A0", "00", "B0", "00", "B7", "00", 
+"00", "00", "00", "B8", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "A8", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "A9", 
+"FE", "E0", "E1", "F6", "E4", "E5", "F4", "E3", 
+"F5", "E8", "E9", "EA", "EB", "EC", "ED", "EE", 
+"EF", "FF", "F0", "F1", "F2", "F3", "E6", "E2", 
+"FC", "FB", "E7", "F8", "FD", "F9", "F7", "FA", 
+"DE", "C0", "C1", "D6", "C4", "C5", "D4", "C3", 
+"D5", "C8", "C9", "CA", "CB", "CC", "CD", "CE", 
+"CF", "DF", "D0", "D1", "D2", "D3", "C6", "C2", 
+"DC", "DB", "C7", "D8", "DD", "D9", "D7", "DA", 
+};
+char koi8u_2_cp1251[128][3] = {
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "00", "00", "00", 
+"00", "00", "00", "00", "00", "95", "00", "00", 
+"00", "00", "A0", "00", "B0", "00", "B7", "00", 
+"00", "00", "00", "B8", "BA", "00", "B3", "BF", 
+"00", "00", "00", "00", "00", "B4", "00", "00", 
+"00", "00", "00", "A8", "AA", "00", "B2", "AF", 
+"00", "00", "00", "00", "00", "A5", "00", "A9", 
+"FE", "E0", "E1", "F6", "E4", "E5", "F4", "E3", 
+"F5", "E8", "E9", "EA", "EB", "EC", "ED", "EE", 
+"EF", "FF", "F0", "F1", "F2", "F3", "E6", "E2", 
+"FC", "FB", "E7", "F8", "FD", "F9", "F7", "FA", 
+"DE", "C0", "C1", "D6", "C4", "C5", "D4", "C3", 
+"D5", "C8", "C9", "CA", "CB", "CC", "CD", "CE", 
+"CF", "DF", "D0", "D1", "D2", "D3", "C6", "C2", 
+"DC", "DB", "C7", "D8", "DD", "D9", "D7", "DA", 
+};
+char maccyr_2_cp1251[128][3] = {
+"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
+"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
+"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
+"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
+"86", "B0", "A5", "00", "A7", "95", "B6", "B2", 
+"AE", "A9", "99", "80", "90", "00", "81", "83", 
+"00", "B1", "00", "00", "B3", "B5", "B4", "A3", 
+"AA", "BA", "AF", "BF", "8A", "9A", "8C", "9C", 
+"BC", "BD", "AC", "00", "00", "00", "00", "AB", 
+"BB", "85", "A0", "8E", "9E", "8D", "9D", "BE", 
+"96", "97", "93", "94", "91", "92", "00", "84", 
+"A1", "A2", "8F", "9F", "B9", "A8", "B8", "FF", 
+"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
+"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
+"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
+"F8", "F9", "FA", "FB", "FC", "FD", "FE", "88", 
+};
+char macukr_2_cp1251[128][3] = {
+"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
+"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
+"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
+"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
+"86", "B0", "A5", "00", "A7", "95", "B6", "B2", 
+"AE", "A9", "99", "80", "90", "00", "81", "83", 
+"00", "B1", "00", "00", "B3", "B5", "B4", "A3", 
+"AA", "BA", "AF", "BF", "8A", "9A", "8C", "9C", 
+"BC", "BD", "AC", "00", "00", "00", "00", "AB", 
+"BB", "85", "A0", "8E", "9E", "8D", "9D", "BE", 
+"96", "97", "93", "94", "91", "92", "00", "84", 
+"A1", "A2", "8F", "9F", "B9", "A8", "B8", "FF", 
+"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
+"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
+"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
+"F8", "F9", "FA", "FB", "FC", "FD", "FE", "A4", 
+};
